# Optimization

Optimization commands are used to perform topology, shape, or sizing optimization of your model given a set of objectives and a set of restrictions.

## Create optimization tasks

```{eval-rst}
.. autoclass:: abaqus.Optimization.OptimizationTaskModel.OptimizationTaskModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Assign features to optimization tasks

```{eval-rst}
.. autoclass:: abaqus.Optimization.OptimizationTask.OptimizationTask
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### BeadFixedRegion

```{eval-rst}
.. autoclass:: abaqus.Optimization.BeadFixedRegion.BeadFixedRegion
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### BeadGrowth

```{eval-rst}
.. autoclass:: abaqus.Optimization.BeadGrowth.BeadGrowth
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### BeadPenetrationCheck

```{eval-rst}
.. autoclass:: abaqus.Optimization.BeadPenetrationCheck.BeadPenetrationCheck
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### BeadPlanarSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.BeadPlanarSymmetry.BeadPlanarSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### BeadPointSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.BeadPointSymmetry.BeadPointSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### BeadRotationalSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.BeadRotationalSymmetry.BeadRotationalSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### BeadTask

```{eval-rst}
.. autoclass:: abaqus.Optimization.BeadTask.BeadTask
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### CombinedTermDesignResponse

```{eval-rst}
.. autoclass:: abaqus.Optimization.CombinedTermDesignResponse.CombinedTermDesignResponse
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DesignDirection

```{eval-rst}
.. autoclass:: abaqus.Optimization.DesignDirection.DesignDirection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DesignResponse

```{eval-rst}
.. autoclass:: abaqus.Optimization.DesignResponse.DesignResponse
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DrillControl

```{eval-rst}
.. autoclass:: abaqus.Optimization.DrillControl.DrillControl
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FixedRegion

```{eval-rst}
.. autoclass:: abaqus.Optimization.FixedRegion.FixedRegion
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FrozenArea

```{eval-rst}
.. autoclass:: abaqus.Optimization.FrozenArea.FrozenArea
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### GeometricRestriction

```{eval-rst}
.. autoclass:: abaqus.Optimization.GeometricRestriction.GeometricRestriction
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Growth

```{eval-rst}
.. autoclass:: abaqus.Optimization.Growth.Growth
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LocalStopCondition

```{eval-rst}
.. autoclass:: abaqus.Optimization.LocalStopCondition.LocalStopCondition
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ObjectiveFunction

```{eval-rst}
.. autoclass:: abaqus.Optimization.ObjectiveFunction.ObjectiveFunction
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OptimizationConstraint

```{eval-rst}
.. autoclass:: abaqus.Optimization.OptimizationConstraint.OptimizationConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OptimizationObjective

```{eval-rst}
.. autoclass:: abaqus.Optimization.OptimizationObjective.OptimizationObjective
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OptimizationObjectiveArray

```{eval-rst}
.. autoclass:: abaqus.Optimization.OptimizationObjectiveArray.OptimizationObjectiveArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### PenetrationCheck

```{eval-rst}
.. autoclass:: abaqus.Optimization.PenetrationCheck.PenetrationCheck
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ShapeDemoldControl

```{eval-rst}
.. autoclass:: abaqus.Optimization.ShapeDemoldControl.ShapeDemoldControl
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ShapeMemberSize

```{eval-rst}
.. autoclass:: abaqus.Optimization.ShapeMemberSize.ShapeMemberSize
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ShapePlanarSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.ShapePlanarSymmetry.ShapePlanarSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ShapePointSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.ShapePointSymmetry.ShapePointSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ShapeRotationalSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.ShapeRotationalSymmetry.ShapeRotationalSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ShapeTask

```{eval-rst}
.. autoclass:: abaqus.Optimization.ShapeTask.ShapeTask
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SingleTermDesignResponse

```{eval-rst}
.. autoclass:: abaqus.Optimization.SingleTermDesignResponse.SingleTermDesignResponse
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SizingClusterAreas

```{eval-rst}
.. autoclass:: abaqus.Optimization.SizingClusterAreas.SizingClusterAreas
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SizingCyclicSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.SizingCyclicSymmetry.SizingCyclicSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SizingFrozenArea

```{eval-rst}
.. autoclass:: abaqus.Optimization.SizingFrozenArea.SizingFrozenArea
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SizingMemberSize

```{eval-rst}
.. autoclass:: abaqus.Optimization.SizingMemberSize.SizingMemberSize
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SizingPlanarSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.SizingPlanarSymmetry.SizingPlanarSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SizingPointSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.SizingPointSymmetry.SizingPointSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SizingRotationalSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.SizingRotationalSymmetry.SizingRotationalSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SizingTask

```{eval-rst}
.. autoclass:: abaqus.Optimization.SizingTask.SizingTask
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SlideRegionControl

```{eval-rst}
.. autoclass:: abaqus.Optimization.SlideRegionControl.SlideRegionControl
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### StampControl

```{eval-rst}
.. autoclass:: abaqus.Optimization.StampControl.StampControl
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### StepOption

```{eval-rst}
.. autoclass:: abaqus.Optimization.StepOption.StepOption
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### StepOptionArray

```{eval-rst}
.. autoclass:: abaqus.Optimization.StepOptionArray.StepOptionArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### StopCondition

```{eval-rst}
.. autoclass:: abaqus.Optimization.StopCondition.StopCondition
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TopologyCyclicSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.TopologyCyclicSymmetry.TopologyCyclicSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TopologyDemoldControl

```{eval-rst}
.. autoclass:: abaqus.Optimization.TopologyDemoldControl.TopologyDemoldControl
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TopologyMemberSize

```{eval-rst}
.. autoclass:: abaqus.Optimization.TopologyMemberSize.TopologyMemberSize
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TopologyPlanarSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.TopologyPlanarSymmetry.TopologyPlanarSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TopologyPointSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.TopologyPointSymmetry.TopologyPointSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TopologyRotationalSymmetry

```{eval-rst}
.. autoclass:: abaqus.Optimization.TopologyRotationalSymmetry.TopologyRotationalSymmetry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TopologyTask

```{eval-rst}
.. autoclass:: abaqus.Optimization.TopologyTask.TopologyTask
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TurnControl

```{eval-rst}
.. autoclass:: abaqus.Optimization.TurnControl.TurnControl
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
